#[repr(C)]pub struct UartRegisters {
pub fifo: ReadWrite<u32>,
pub control: ReadWrite<u32, Register>,
pub status: ReadOnly<u32, Register>,
}Expand description
Describes the UART’s registers
Fields
fifo: ReadWrite<u32>Data FIFO
- Read here to get a byte from the FIFO
- Write here to put a byte into the FIFO
control: ReadWrite<u32, Register>Control Register
Adjust various UART settings
status: ReadOnly<u32, Register>Status Register
Read-only UART status